package App::Cme ;

use strict;
use warnings;
use 5.10.1;

# See App::Cmd for explanations on this file

use App::Cmd::Setup -app;

1;

# ABSTRACT: Configuration data checker or editor based on Config::Model


